package com.ruoyi.excel.wecom.service.impl;

import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.spring.SpringUtils;
import com.ruoyi.excel.wecom.domain.CorpInfo;
import com.ruoyi.excel.wecom.mapper.CorpInfoMapper;
import com.ruoyi.excel.wecom.service.ICorpInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import java.util.List;

/**
 * 企业信息Service业务层处理
 */
@Service
public class CorpInfoServiceImpl implements ICorpInfoService {
    private static final String CURRENT_CORP_KEY_PREFIX_ONLY = "current_corp_only:";
    @Autowired
    private CorpInfoMapper corpInfoMapper;

    @PostConstruct
    public void setCorpInfoWhenOne() {
        List<CorpInfo> corpInfos = corpInfoMapper.selectList(null);
        if(corpInfos.size() == 1) {
            RedisCache redisCache = SpringUtils.getBean(RedisCache.class);
            String corpId = corpInfos.get(0).getCorpId();
            redisCache.setCacheObject(CURRENT_CORP_KEY_PREFIX_ONLY, corpId);
        }
    }
    /**
     * 查询企业信息列表
     *
     * @param corpInfo 企业信息
     * @return 企业信息集合
     */
    @Override
    public List<CorpInfo> selectCorpInfoList(CorpInfo corpInfo) {
        return corpInfoMapper.selectCorpInfoList(corpInfo);
    }

    /**
     * 根据企业ID查询企业信息
     *
     * @param corpId 企业ID
     * @return 企业信息
     */
    @Override
    public CorpInfo selectCorpInfoByCorpId(String corpId) {
        return corpInfoMapper.selectCorpInfoByCorpId(corpId);
    }

    /**
     * 根据ID查询企业信息
     *
     * @param id 主键ID
     * @return 企业信息
     */
    @Override
    public CorpInfo selectCorpInfoById(Long id) {
        return corpInfoMapper.selectById(id);
    }

    /**
     * 新增企业信息
     *
     * @param corpInfo 企业信息
     * @return 结果
     */
    @Override
    public int insertCorpInfo(CorpInfo corpInfo) {
        return corpInfoMapper.insert(corpInfo);
    }

    /**
     * 修改企业信息
     *
     * @param corpInfo 企业信息
     * @return 结果
     */
    @Override
    public int updateCorpInfo(CorpInfo corpInfo) {
        return corpInfoMapper.updateById(corpInfo);
    }

    /**
     * 批量删除企业信息
     *
     * @param ids 需要删除的企业信息主键集合
     * @return 结果
     */
    @Override
    public int deleteCorpInfoByIds(Long[] ids) {
        int count = 0;
        for (Long id : ids) {
            count += corpInfoMapper.deleteById(id);
        }
        return count;
    }

    /**
     * 删除企业信息
     *
     * @param id 企业信息主键
     * @return 结果
     */
    @Override
    public int deleteCorpInfoById(Long id) {
        return corpInfoMapper.deleteById(id);
    }
}
